MediaQueryUtils extension

on

Properties

bottomPadding → double

Available on BuildContext, provided by the MediaQueryUtils extension

no setter
height → double

Available on BuildContext, provided by the MediaQueryUtils extension

no setter
isDarkMode → bool

Available on BuildContext, provided by the MediaQueryUtils extension

Checks if the current theme is in dark mode
no setter
isLandscape → bool

Available on BuildContext, provided by the MediaQueryUtils extension

no setter
isLightMode → bool

Available on BuildContext, provided by the MediaQueryUtils extension

Checks if the current theme is in light mode
no setter
isPortrait → bool

Available on BuildContext, provided by the MediaQueryUtils extension

no setter
topPadding → double

Available on BuildContext, provided by the MediaQueryUtils extension

no setter
width → double

Available on BuildContext, provided by the MediaQueryUtils extension

no setter