TouchControl extension

on

Methods

customTouchControl({required bool enable, VoidCallback? onTapWhileDisabled}) → Widget

Available on Widget, provided by the TouchControl extension

Enables or disables touch with a custom gesture detector
touchDisabled({bool disable = true}) → Widget

Available on Widget, provided by the TouchControl extension

Disables touch interactions for the widget by wrapping it with AbsorbPointer.
touchDisabledWithOpacity({bool disable = true, double disabledOpacity = 0.5}) → Widget

Available on Widget, provided by the TouchControl extension

Disables touch interactions with visual feedback using Opacity.
touchIgnored({bool ignore = true}) → Widget

Available on Widget, provided by the TouchControl extension

Enables or disables touch interactions with feedback using IgnorePointer.